pygeai.cli.commands package
===========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.cli.commands.flows
   pygeai.cli.commands.lab

Submodules
----------

pygeai.cli.commands.admin module
--------------------------------

.. automodule:: pygeai.cli.commands.admin
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.assistant module
------------------------------------

.. automodule:: pygeai.cli.commands.assistant
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.auth module
-------------------------------

.. automodule:: pygeai.cli.commands.auth
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.base module
-------------------------------

.. automodule:: pygeai.cli.commands.base
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.builders module
-----------------------------------

.. automodule:: pygeai.cli.commands.builders
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.chat module
-------------------------------

.. automodule:: pygeai.cli.commands.chat
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.common module
---------------------------------

.. automodule:: pygeai.cli.commands.common
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.configuration module
----------------------------------------

.. automodule:: pygeai.cli.commands.configuration
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.docs module
-------------------------------

.. automodule:: pygeai.cli.commands.docs
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.embeddings module
-------------------------------------

.. automodule:: pygeai.cli.commands.embeddings
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.evaluation module
-------------------------------------

.. automodule:: pygeai.cli.commands.evaluation
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.feedback module
-----------------------------------

.. automodule:: pygeai.cli.commands.feedback
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.files module
--------------------------------

.. automodule:: pygeai.cli.commands.files
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.gam module
------------------------------

.. automodule:: pygeai.cli.commands.gam
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.llm module
------------------------------

.. automodule:: pygeai.cli.commands.llm
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.migrate module
----------------------------------

.. automodule:: pygeai.cli.commands.migrate
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.options module
----------------------------------

.. automodule:: pygeai.cli.commands.options
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.organization module
---------------------------------------

.. automodule:: pygeai.cli.commands.organization
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.rag module
------------------------------

.. automodule:: pygeai.cli.commands.rag
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.rerank module
---------------------------------

.. automodule:: pygeai.cli.commands.rerank
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.secrets module
----------------------------------

.. automodule:: pygeai.cli.commands.secrets
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.usage\_limits module
----------------------------------------

.. automodule:: pygeai.cli.commands.usage_limits
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.validators module
-------------------------------------

.. automodule:: pygeai.cli.commands.validators
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.cli.commands.version module
----------------------------------

.. automodule:: pygeai.cli.commands.version
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.cli.commands
   :members:
   :show-inheritance:
   :undoc-members:
